@@ -20,6 +20,8 @@
 #ifndef PA_UTILS_H
 #define PA_UTILS_H
 
+#include <QStringList>
+
 #include <pulse/context.h>
 #include <pulse/introspect.h>
 
@@ -29,7 +31,7 @@
 
 void get_sink_info_list_callback(pa_context *context, const pa_sink_info *list, int length, void *data);
 
-const char *get_monitor_name();
+const QStringList *get_source_names();
 
 bool pa_available();
 
