@@ -21,21 +21,20 @@
 
 #include "pa_utils.h"
 
-PulseAudioRecordBackend::PulseAudioRecordBackend()
+PulseAudioRecordBackend::PulseAudioRecordBackend(QString source)
 {
-    qDebug("Using PulseAudio for recording...");
-    context_create();
-    source = get_monitor_name();
-    qDebug("Recording from: %s", source);
-    connect_to_vu_meter_stream(source, this);
+    this->source = new QString(source);
+    qDebug("Recording from: %s", this->source->toLocal8Bit().constData());
+    connect_to_vu_meter_stream(this->source->toLocal8Bit().constData(), this);
 }
 
 PulseAudioRecordBackend::~PulseAudioRecordBackend(){
     context_stop();
+    delete source;
 }
 
 void PulseAudioRecordBackend::startRecordHook(){
-    connect_to_record_stream(source, this);
+    connect_to_record_stream(source->toLocal8Bit().constData(), this);
 }
 
 void PulseAudioRecordBackend::stopRecordHook(){
