@@ -21,13 +21,14 @@
 #define PULSEAUDIORECORDBACKEND_H
 
 #include <QObject>
+#include <QString>
 
 #include "src/io/audio/abstractaudiorecorderbackend.h"
 
 class PulseAudioRecordBackend : public AbstractAudioRecorderBackend
 {
 public:
-    PulseAudioRecordBackend();
+    PulseAudioRecordBackend(QString source);
     ~PulseAudioRecordBackend();
 
 protected:
@@ -35,7 +36,7 @@ protected:
     void stopRecordHook();
 
 private:
-    const char *source;
+    QString *source;
 
 };
 
